==> 1.0.2_20240315_release.zip: app/service/admin/S_category.php <==
<?php

namespace app\service\admin;

use app\db\admin\D_category;

class S_category
{
    public $d_category;

    public function __construct()
    {
        $this->d_category = new D_category();
    }

    /**
     * 更新 单条-linkurl 数据
     * @param string $paramObj
     * @return array
     */
    public function updateRowLinkurl($paramObj=""){
        return $this->d_category->updateRowLinkurl($paramObj);
    }

    /**
     * 更新 linkurl 数据
     * @param string $paramObj
     * @return array
     */
    public function updateLinkurl($paramObj=""){
        return $this->d_category->updateLinkurl($paramObj);
    }

    /**
     * 文章列表数据
     * @param string $paramObj
     * @return array
     */
    public function listData($paramObj=""){
        return $this->d_category->listData($paramObj);
    }

    /**
     * 获取数据详情
     * @param string $paramObj
     * @return array
     */
    public function info($paramObj=""){
        return $this->d_category->info($paramObj);
    }

    /**
     * 获取子元素数据
     * @param string $paramObj
     * @return array
     */
    public function getChildVal($paramObj=""){
        return $this->d_category->getChildVal($paramObj);
    }

    /**
     * 获取父级元素数据
     * @param string $paramObj
     * @return array
     */
    public function getParentVal($paramObj=""){
        return $this->d_category->getParentVal($paramObj);
    }

    /**
     * 所有数据
     * @param string $paramObj
     * @return array
     */
    public function allData($paramObj=""){
        return $this->d_category->allData($paramObj);
    }

    /**
     * 创建数据
     * @param string $paramObj
     * @return array
     */
    public function store($paramObj=""){
        return $this->d_category->store($paramObj);
    }

    /**
     * 更新数据
     * @param string $paramObj
     * @return array
     */
    public function update($paramObj=""){
        return $this->d_category->update($paramObj);
    }

    /**
     * 删除数据
     * @param string $paramObj
     * @return array
     */
    public function delete($paramObj=""){
        return $this->d_category->delete($paramObj);
    }

    public function __call($name,$arguments)
    {
        return recordLogMsgLevelTwo(app("errorLevel")::E_WARNING,app("errorCode")::UNDEFINED_METHOD,lang("sys.noMethodDefined"),$name,$arguments);
    }
}

==> 1.0.20_20240718_release.zip: app/service/admin/S_category.php <==
<?php

namespace app\service\admin;

use app\db\admin\D_category;

class S_category
{
    public $d_category;

    public function __construct()
    {
        $this->d_category = new D_category();
    }

    /**
     * 更新 单条-linkurl 数据
     * @param string $paramObj
     * @return array
     */
    public function updateRowLinkurl($paramObj=""){
        return $this->d_category->updateRowLinkurl($paramObj);
    }

    /**
     * 更新 linkurl 数据
     * @param string $paramObj
     * @return array
     */
    public function updateLinkurl($paramObj=""){
        return $this->d_category->updateLinkurl($paramObj);
    }

    /**
     * 获取模块分类
     * @param string $paramObj
     * @return array
     */
    public function getModuleData($paramObj=""){
        return $this->d_category->getModuleData($paramObj);
    }

    /**
     * 文章列表数据
     * @param string $paramObj
     * @return array
     */
    public function listData($paramObj=""){
        return $this->d_category->listData($paramObj);
    }

    /**
     * 获取数据详情
     * @param string $paramObj
     * @return array
     */
    public function info($paramObj=""){
        return $this->d_category->info($paramObj);
    }

    /**
     * 获取子元素数据
     * @param string $paramObj
     * @return array
     */
    public function getChildVal($paramObj=""){
        return $this->d_category->getChildVal($paramObj);
    }

    /**
     * 获取父级元素数据
     * @param string $paramObj
     * @return array
     */
    public function getParentVal($paramObj=""){
        return $this->d_category->getParentVal($paramObj);
    }

    /**
     * 所有数据
     * @param string $paramObj
     * @return array
     */
    public function allData($paramObj=""){
        return $this->d_category->allData($paramObj);
    }

    /**
     * 创建数据
     * @param string $paramObj
     * @return array
     */
    public function store($paramObj=""){
        return $this->d_category->store($paramObj);
    }

    /**
     * 更新数据
     * @param string $paramObj
     * @return array
     */
    public function update($paramObj=""){
        return $this->d_category->update($paramObj);
    }

    /**
     * 删除数据
     * @param string $paramObj
     * @return array
     */
    public function delete($paramObj=""){
        return $this->d_category->delete($paramObj);
    }

    public function __call($name,$arguments)
    {
        return recordLogMsgLevelTwo(app("errorLevel")::E_WARNING,app("errorCode")::UNDEFINED_METHOD,lang("sys.noMethodDefined"),$name,$arguments);
    }
}
